@@ -180,39 +180,40 @@ class TaskScheduler(object):
         self.scheduler = scheduler
         setattr(self.app, "scheduler", self.scheduler)
 
-    def insert_task(
+    def add_task(
             self,
             func: Callable,
-            interval: int,
             job_id: str,
+            trigger: str,
             crawler_info: Dict = None,
-            trigger: str = "interval",
+            **trigger_args
     ) -> None:
-        redis_dict = dict()
-        redis_dict['func'] = obj_to_ref(func)
-        redis_dict['interval'] = interval
-        redis_dict['job_id'] = job_id
-        redis_dict['trigger'] = trigger
-        if crawler_info is not None:
-            redis_dict.update(crawler_info)
-        self.register_base_scheduler.insert_task(redis_dict)
+        '''
+        :param trigger: interval 、 date or cron
+        '''
+        task_info = dict()
+        task_info['func'] = obj_to_ref(func)
+        task_info['job_id'] = job_id
+        task_info['trigger'] = trigger
+        task_info['crawler_info'] = crawler_info
+        task_info['trigger_args'] = trigger_args
+        self.register_base_scheduler.insert_task(task_info=task_info)
 
-    def update_task(
-            self,
-            func: Callable,
-            interval: int,
-            job_id: str,
-            crawler_info: Dict = None,
-            trigger: str = "interval",
-    ) -> None:
-        redis_dict = dict()
-        redis_dict['func'] = obj_to_ref(func)
-        redis_dict['interval'] = interval
-        redis_dict['job_id'] = job_id
-        redis_dict['trigger'] = trigger
-        if crawler_info is not None:
-            redis_dict.update(crawler_info)
-        self.register_base_scheduler.update_task(redis_dict)
+    # def update_task(
+    #         self,
+    #         func: Callable,
+    #         job_id: str,
+    #         trigger: str,
+    #         crawler_info: Dict = None,
+    #         **trigger_args
+    # ) -> None:
+    #     task_info = dict()
+    #     task_info['func'] = obj_to_ref(func)
+    #     task_info['job_id'] = job_id
+    #     task_info['trigger'] = trigger
+    #     task_info['crawler_info'] = crawler_info
+    #     task_info['trigger_args'] = trigger_args
+    #     self.register_base_scheduler.update_task(task_info=task_info)
 
     def delete_task(
             self,
